bd_tree_prior_to_xml_prior_distr: Creates the tree prior section in the prior section of
the prior section of the distribution section
of a BEAST2 XML parameter file for a Birth-Death tree prior
Description
Creates the tree prior section in the prior section of
the prior section of the distribution section
of a BEAST2 XML parameter file for a Birth-Death tree prior
Usage
bd_tree_prior_to_xml_prior_distr(bd_tree_prior)
Arguments
bd_tree_prior
a Birth-Death tree prior, as created
by create_bd_tree_prior