cbs_tree_prior_to_xml_prior_distr: Creates the tree prior section in the prior section of
the prior section of the distribution section
of a BEAST2 XML parameter file for a Birth-Death tree prior
Description
Creates the tree prior section in the prior section of
the prior section of the distribution section
of a BEAST2 XML parameter file for a Birth-Death tree prior
Usage
cbs_tree_prior_to_xml_prior_distr(cbs_tree_prior)
Arguments
cbs_tree_prior
a Coalescent Bayesian Skyline tree prior,
as returned by create_cbs_tree_prior