ccp_tree_prior_to_xml_prior_distr: Creates the tree prior section in the prior section of
the prior section of the distribution section
of a BEAST2 XML parameter file for a
Coalescent Constant Population tree prior
Description
Creates the tree prior section in the prior section of
the prior section of the distribution section
of a BEAST2 XML parameter file for a
Coalescent Constant Population tree prior
Usage
ccp_tree_prior_to_xml_prior_distr(ccp_tree_prior)
Arguments
ccp_tree_prior
a Coalescent Constant Population tree prior,
as returned by create_ccp_tree_prior