cep_tree_prior_to_xml_prior_distr: Creates the tree prior section in the prior section of
the prior section of the distribution section
of a BEAST2 XML parameter file for a
Coalescent Exponential Population tree prior
Description
Creates the tree prior section in the prior section of
the prior section of the distribution section
of a BEAST2 XML parameter file for a
Coalescent Exponential Population tree prior
Usage
cep_tree_prior_to_xml_prior_distr(cep_tree_prior)
Arguments
cep_tree_prior
a Coalescent Exponential Population tree prior,
as returned by create_cep_tree_prior