Creates the clock model's XML for the tracelog section
Usage
clock_model_to_xml_tracelog(inference_model)
Value
a character vector of XML strings
Arguments
inference_model
a Bayesian phylogenetic inference model.
An inference model is the complete model setup in which a site model,
clock model, tree prior and more are specified.
Use create_inference_model to create an inference model.
Use check_inference_model to check if an inference model is valid.
Use rename_inference_model_filenames to rename the files in an
inference model.