Learn R Programming

beautier (version 2.6.5)

create_beauti_options: Function to create a set of BEAUti options.

Description

BEAUti options are settings that differ between BEAUti version. The use of these options is mostly for testing older versions Whatever option chosen here, the created XML file will be valid.

Usage

create_beauti_options(
  capitalize_first_char_id = FALSE,
  nucleotides_uppercase = FALSE,
  beast2_version = "2.4",
  required = "",
  sequence_indent = 20
)

Value

a BEAUti options structure

Arguments

capitalize_first_char_id

must the ID of alignment start with a capital? TRUE if yes, FALSE if it can be left lower case (if it is lowercase)

nucleotides_uppercase

must the nucleotides of the DNA sequence be in uppercase?

beast2_version

the BEAST2 version

required

things that may be required, for example BEAST v2.5.0

sequence_indent

the number of spaces the XML sequence lines are indented

Author

Richèl J.C. Bilderbeek

Details

Available BEAUti options are:

  • create_beauti_options_v2_4

  • create_beauti_options_v2_6

Examples

Run this code
if (is_on_ci()) {

  check_empty_beautier_folder()

  beauti_options <- create_beauti_options_v2_4()
  xml <- create_beast2_input(
    get_fasta_filename(),
    beauti_options = beauti_options
  )

  check_empty_beautier_folder()
}

Run the code above in your browser using DataLab