branchRateModel section
of the XML as text.Creates the branchRateModel section
of the XML as text.
create_branch_rate_model_xml(inference_model)a character vector of XML strings
a Bayesian phylogenetic inference model. An inference model is the complete model setup in which a site model, clock model, tree prior and more are specified. Use create_inference_model to create an inference model. Use check_inference_model to check if an inference model is valid. Use rename_inference_model_filenames to rename the files in an inference model.
Richèl J.C. Bilderbeek
This function will be called only if there are no MRCA priors.
The distribution tag (with ID equals treeLikelihood)
has these elements:
<branchRateModel[...]>
[...]
</branchRateModel>
When there is a strict clock, create_branch_rate_model_sc_xml is called. When there is an RLN clock, create_branch_rate_model_rln_xml is called.
Zooming out:
<beast[...]>
<run[...]>
<distribution id="posterior"[...]>
<distribution id="likelihood"[...]>
<distribution id="treeLikelihood"[...]>
[...] [this section]
</distribution>
</distribution>
</distribution>
</run>
</beast>