screenlog objectCreate a screenlog object
create_test_screenlog(
filename = beautier::create_temp_screenlog_filename(),
log_every = 1000,
mode = "autodetect",
sanitise_headers = FALSE,
sort = "none"
)name of the file to store the posterior screens
phylogenies to. By default, this is $(screen).screens
number of MCMC states between writing to file
mode how to log. Valid values are the ones returned by get_log_modes
set to TRUE to sanitise the headers of the log file
how to sort the log. Valid values are the ones returned by get_log_sorts