treelog objectCreate a treelog object
create_test_treelog(
filename = create_temp_treelog_filename(),
log_every = 1000,
mode = "tree",
sanitise_headers = FALSE,
sort = "none"
)name of the file to store the posterior trees
number of MCMC states between writing to file
mode how to log. Valid values are the ones returned by get_log_modes
set to TRUE to sanitise the headers of the log file
how to sort the log. Valid values are the ones returned by get_log_sorts