tracelog objectCreate a tracelog object
create_tracelog(
filename = NA,
log_every = 1000,
mode = "autodetect",
sanitise_headers = TRUE,
sort = "smart"
)name of the file to store the posterior traces.
Use NA to use the filename [alignment_id].log,
where alignment_id is obtained using get_alignment_id
number of MCMC states between writing to file
mode how to log. Valid values are the ones returned by get_log_modes
set to TRUE to sanitise the headers of the log file
how to sort the log. Valid values are the ones returned by get_log_sorts