Learn R Programming

beautier (version 2.6.5)

gamma_site_models_to_xml_prior_distr: Creates the gamma site models section in the distribution section of a BEAST2 XML parameter file

Description

Creates the gamma site models section in the distribution section of a BEAST2 XML parameter file

Usage

gamma_site_models_to_xml_prior_distr(site_models)

Value

lines of XML text

Arguments

site_models

one or more site models, as returned by create_site_model

Author

Richèl J.C. Bilderbeek