Learn R Programming

beautier (version 2.6.9)

get_replace_dir_fun: Get a function to replace the directory of a filename

Description

Get a function to replace the directory of a filename

Usage

get_replace_dir_fun(new_dir_name = "")

Arguments

new_dir_name

the new directory name