Learn R Programming

beautier (version 2.6.5)

has_rln_clock_model: Determine if the inference_model uses a relaxed log-normal clock model.

Description

Determine if the inference_model uses a relaxed log-normal clock model.

Usage

has_rln_clock_model(inference_model)

Value

TRUE if the inference_model uses a relaxed log-normal clock model, FALSE otherwise

Arguments

inference_model

a Bayesian phylogenetic inference model. An inference model is the complete model setup in which a site model, clock model, tree prior and more are specified. Use create_inference_model to create an inference model. Use check_inference_model to check if an inference model is valid. Use rename_inference_model_filenames to rename the files in an inference model.

Author

Richèl J.C. Bilderbeek

Examples

Run this code
check_empty_beautier_folder()

# Yes, has a RLN clock model
has_rln_clock_model(
  create_inference_model(clock_model = create_rln_clock_model())
)

# No RLN clock model
has_rln_clock_model(
  create_inference_model(clock_model = create_strict_clock_model())
)

check_empty_beautier_folder()

Run the code above in your browser using DataLab