Learn R Programming

beautier (version 2.6.5)

is_cbs_tree_prior: Determine if the object is a valid constant coalescent Bayesian skyline prior

Description

Determine if the object is a valid constant coalescent Bayesian skyline prior

Usage

is_cbs_tree_prior(x)

Value

TRUE if x is a valid constant coalescent Bayesian skyline prior, FALSE otherwise

Arguments

x

an object, to be determined if it is a valid constant coalescent Bayesian skyline prior

Author

Richèl J.C. Bilderbeek

See Also

Use create_cbs_tree_prior to create a valid coalescent Bayes skyline tree prior

Examples

Run this code
check_empty_beautier_folder()

  testit::assert(!is_cbs_tree_prior(create_bd_tree_prior()))
  testit::assert( is_cbs_tree_prior(create_cbs_tree_prior()))
  testit::assert(!is_cbs_tree_prior(create_ccp_tree_prior()))
  testit::assert(!is_cbs_tree_prior(create_cep_tree_prior()))
  testit::assert(!is_cbs_tree_prior(create_yule_tree_prior()))

check_empty_beautier_folder()

Run the code above in your browser using DataLab