powered by
Determine if the object is a valid Nested-Sampling MCMC, as used in [1]
is_mcmc_nested_sampling(x)
TRUE if x is a valid Nested-Sampling MCMC, FALSE otherwise
an object, to be determined if it is a valid MCMC
Richèl J.C. Bilderbeek
* [1] Patricio Maturana Russel, Brendon J Brewer, Steffen Klaere, Remco R Bouckaert; Model Selection and Parameter Inference in Phylogenetics Using Nested Sampling, Systematic Biology, 2018, syy050, https://doi.org/10.1093/sysbio/syy050
Use create_ns_mcmc to create an NS MCMC
check_empty_beautier_folder() # TRUE is_nested_sampling_mcmc(create_ns_mcmc()) # FALSE is_nested_sampling_mcmc(create_mcmc()) is_nested_sampling_mcmc("nonsense") check_empty_beautier_folder()
Run the code above in your browser using DataLab