Learn R Programming

beautier (version 2.6.5)

is_tree_prior: Determine if an object is a valid tree prior

Description

Determine if an object is a valid tree prior

Usage

is_tree_prior(x)

Value

TRUE if x is a valid tree_prior, FALSE otherwise

Arguments

x

an object

Author

Richèl J.C. Bilderbeek

See Also

tree priors can be created by create_tree_prior

Examples

Run this code
check_empty_beautier_folder()

testit::assert(is_tree_prior(create_bd_tree_prior()))
testit::assert(is_tree_prior(create_yule_tree_prior()))
testit::assert(!is_tree_prior("nonsense"))

check_empty_beautier_folder()

Run the code above in your browser using DataLab