gamma_site_model_to_xml_prior_distr: Creates the gamma site models section in the distribution section
of a BEAST2 XML parameter file
Description
Creates the gamma site models section in the distribution section
of a BEAST2 XML parameter file
Usage
gamma_site_model_to_xml_prior_distr(site_model)
Arguments
- site_model
a site model,
as returned by create_site_model
Author
Richèl J.C. Bilderbeek